@@ -28,7 +28,7 @@ def _get_kwargs(
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _build_response(*, response: httpx.Response) -> Response[None]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -41,23 +41,13 @@ def sync_detailed(
     *,
     client: Client,
     json_body: ValidateIdJsonBody,
-) -> Response[Any]:
-    """validate id
-
-    Args:
-        json_body (ValidateIdJsonBody):
-
-    Returns:
-        Response[Any]
-    """
-
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
         json_body=json_body,
     )
 
     response = httpx.post(
-        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -68,22 +58,13 @@ async def asyncio_detailed(
     *,
     client: Client,
     json_body: ValidateIdJsonBody,
-) -> Response[Any]:
-    """validate id
-
-    Args:
-        json_body (ValidateIdJsonBody):
-
-    Returns:
-        Response[Any]
-    """
-
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
         json_body=json_body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+    async with httpx.AsyncClient() as _client:
         response = await _client.post(**kwargs)
 
     return _build_response(response=response)
