@@ -149,6 +149,8 @@ from .deno_to_jsonschema_response_200 import DenoToJsonschemaResponse200
 from .deno_to_jsonschema_response_200_args_item import DenoToJsonschemaResponse200ArgsItem
 from .deno_to_jsonschema_response_200_args_item_typ_type_0 import DenoToJsonschemaResponse200ArgsItemTypType0
 from .deno_to_jsonschema_response_200_args_item_typ_type_1 import DenoToJsonschemaResponse200ArgsItemTypType1
+from .deno_to_jsonschema_response_200_args_item_typ_type_2 import DenoToJsonschemaResponse200ArgsItemTypType2
+from .deno_to_jsonschema_response_200_args_item_typ_type_2_list import DenoToJsonschemaResponse200ArgsItemTypType2List
 from .edit_resource import EditResource
 from .edit_resource_type import EditResourceType
 from .edit_resource_value import EditResourceValue
@@ -512,6 +514,8 @@ from .main_arg_signature import MainArgSignature
 from .main_arg_signature_args_item import MainArgSignatureArgsItem
 from .main_arg_signature_args_item_typ_type_0 import MainArgSignatureArgsItemTypType0
 from .main_arg_signature_args_item_typ_type_1 import MainArgSignatureArgsItemTypType1
+from .main_arg_signature_args_item_typ_type_2 import MainArgSignatureArgsItemTypType2
+from .main_arg_signature_args_item_typ_type_2_list import MainArgSignatureArgsItemTypType2List
 from .new_schedule import NewSchedule
 from .new_schedule_args import NewScheduleArgs
 from .new_token import NewToken
@@ -524,6 +528,10 @@ from .python_to_jsonschema_response_200 import PythonToJsonschemaResponse200
 from .python_to_jsonschema_response_200_args_item import PythonToJsonschemaResponse200ArgsItem
 from .python_to_jsonschema_response_200_args_item_typ_type_0 import PythonToJsonschemaResponse200ArgsItemTypType0
 from .python_to_jsonschema_response_200_args_item_typ_type_1 import PythonToJsonschemaResponse200ArgsItemTypType1
+from .python_to_jsonschema_response_200_args_item_typ_type_2 import PythonToJsonschemaResponse200ArgsItemTypType2
+from .python_to_jsonschema_response_200_args_item_typ_type_2_list import (
+    PythonToJsonschemaResponse200ArgsItemTypType2List,
+)
 from .queued_job import QueuedJob
 from .queued_job_args import QueuedJobArgs
 from .queued_job_flow_status import QueuedJobFlowStatus
