@@ -4,6 +4,7 @@ import attr
 
 from ..models.deno_to_jsonschema_response_200_args_item_typ_type_0 import DenoToJsonschemaResponse200ArgsItemTypType0
 from ..models.deno_to_jsonschema_response_200_args_item_typ_type_1 import DenoToJsonschemaResponse200ArgsItemTypType1
+from ..models.deno_to_jsonschema_response_200_args_item_typ_type_2 import DenoToJsonschemaResponse200ArgsItemTypType2
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="DenoToJsonschemaResponse200ArgsItem")
@@ -14,7 +15,11 @@ class DenoToJsonschemaResponse200ArgsItem:
     """ """
 
     name: str
-    typ: Union[DenoToJsonschemaResponse200ArgsItemTypType0, DenoToJsonschemaResponse200ArgsItemTypType1]
+    typ: Union[
+        DenoToJsonschemaResponse200ArgsItemTypType0,
+        DenoToJsonschemaResponse200ArgsItemTypType1,
+        DenoToJsonschemaResponse200ArgsItemTypType2,
+    ]
     has_default: Union[Unset, bool] = UNSET
     default: Union[Unset, None] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -24,6 +29,9 @@ class DenoToJsonschemaResponse200ArgsItem:
         if isinstance(self.typ, DenoToJsonschemaResponse200ArgsItemTypType0):
             typ = self.typ.value
 
+        elif isinstance(self.typ, DenoToJsonschemaResponse200ArgsItemTypType1):
+            typ = self.typ.to_dict()
+
         else:
             typ = self.typ.to_dict()
 
@@ -52,7 +60,11 @@ class DenoToJsonschemaResponse200ArgsItem:
 
         def _parse_typ(
             data: object,
-        ) -> Union[DenoToJsonschemaResponse200ArgsItemTypType0, DenoToJsonschemaResponse200ArgsItemTypType1]:
+        ) -> Union[
+            DenoToJsonschemaResponse200ArgsItemTypType0,
+            DenoToJsonschemaResponse200ArgsItemTypType1,
+            DenoToJsonschemaResponse200ArgsItemTypType2,
+        ]:
             try:
                 typ_type_0: DenoToJsonschemaResponse200ArgsItemTypType0
                 if not isinstance(data, str):
@@ -62,12 +74,21 @@ class DenoToJsonschemaResponse200ArgsItem:
                 return typ_type_0
             except:  # noqa: E722
                 pass
+            try:
+                typ_type_1: DenoToJsonschemaResponse200ArgsItemTypType1
+                if not isinstance(data, dict):
+                    raise TypeError()
+                typ_type_1 = DenoToJsonschemaResponse200ArgsItemTypType1.from_dict(data)
+
+                return typ_type_1
+            except:  # noqa: E722
+                pass
             if not isinstance(data, dict):
                 raise TypeError()
-            typ_type_1: DenoToJsonschemaResponse200ArgsItemTypType1
-            typ_type_1 = DenoToJsonschemaResponse200ArgsItemTypType1.from_dict(data)
+            typ_type_2: DenoToJsonschemaResponse200ArgsItemTypType2
+            typ_type_2 = DenoToJsonschemaResponse200ArgsItemTypType2.from_dict(data)
 
-            return typ_type_1
+            return typ_type_2
 
         typ = _parse_typ(d.pop("typ"))
 
